from src.core.managers import ProjectManager, SectionManager, TaskManager
from src.core.models import Project, Task, Section
from src.utils.utils import get_auth_key
from .cli import CLI

from .utils import Colors


def handle_project_command(args, token):
    print(Colors.wrap(Colors.CYAN, "Project management"))
    project_manager: ProjectManager = ProjectManager(token)
    if args.option in ("c", "create"):
        project_manager.create(args.name, args.description)
    if args.option in ("v", "show", "display", "view"):
        project_manager.view(args.name)
    if args.option in ("u", "update", "e", "edit"):
        project_manager.update(args.name)
    if args.option in ("d", "delete", "r", "remove", "rm"):
        project_manager.remove(args.name)
    if args.option in ("l", "ls", "list"):
        project_manager.list_all(args.type, listing_format=args.format)


def handle_task_command(args, token):
    project_manager: ProjectManager = ProjectManager(token)
    project: Project = project_manager.fetch_by_name(args.project)

    if project:
        print(Colors.wrap(Colors.CYAN, "Task management"))
        task_manager: TaskManager = TaskManager(token, project)
        section_manager: SectionManager = SectionManager(token, project)

        if args.option in ("c", "create"):
            task_description = args.description if args.description else ""
            task_manager.create(args.name, task_description, args.section)

        if args.option in ("u", "update", "e", "edit"):
            task: Task = task_manager.fetch_by_name(args.name)
            task_manager.update(task)

        if args.option in ("ls", "l", "list"):
            task_manager.list_all(args.section, args.status, args.format)

        if args.option in ("m", "move", "mv"):
            task: Task = task_manager.fetch_by_name(args.name)
            section: Section = section_manager.fetch_by_name(args.section)
            task_manager.move(task.id, section.id)
    else:
        print(Colors.wrap(Colors.RED, "Project not found"))


def handle_section_command(args, token):
    project_manager: ProjectManager = ProjectManager(token)
    project: Project = project_manager.fetch_by_name(args.project)

    if project:
        section_manager: SectionManager = SectionManager(token, project)
        print(Colors.wrap(Colors.CYAN, "Section management"))

        if args.option in ("c", "create"):
            section_manager.create(args.name)

        if args.option in ("ls", "l", "list"):
            section_manager.list_all()

        if args.option in ("d", "delete", "r", "remove", "rm"):
            section_manager.delete(args.name)
    else:
        print(Colors.wrap(Colors.RED, "Project not found"))


def main():
    token: str = get_auth_key()

    parser: CLI = CLI()
    args = parser.parse_args()

    if args.command.startswith("p"):
        handle_project_command(args, token)

    if args.command.startswith("t"):
        handle_task_command(args, token)

    if args.command.startswith("s"):
        handle_section_command(args, token)


if __name__ == "__main__":
    main()
