import requests
from typing import List, Optional

from .base import API
from ..core import decorators
from ..core.models import Section


class APISection(API):
    def __init__(self, token: str):
        super().__init__(token)

    @decorators.handle_http_errors
    def create(self, section: Section) -> Section:
        r = requests.post(
            "https://www.meistertask.com/api/projects/{}/sections".format(
                section.project_id
            ),
            headers=self.headers,
            data={"name": section.name},
        )

        if r.status_code != 200:
            raise Exception(
                "Failed to connect to meistertask (code: {})".format(r.status_code)
            )

        return Section.from_json(r.json())

    @decorators.handle_http_errors
    def fetch_all(self, project_id: int) -> List[Section]:

        r = requests.get(
            "https://www.meistertask.com/api/projects/{}/sections".format(project_id),
            headers=self.headers,
        )

        if r.status_code != 200:
            raise Exception(
                "Failed to connect to meistertask (code: {})".format(r.status_code)
            )

        return list(map(lambda section: Section.from_json(section), r.json()))

    @decorators.handle_http_errors
    def fetch_by_name(self, name, project_id: int) -> Optional[Section]:
        sections: List[Section] = self.fetch_all(project_id)
        for section in sections:
            if section.name == name:
                return section

        return None

    @decorators.handle_http_errors
    def delete(self, section_id: int):
        r = requests.put(
            "https://www.meistertask.com/api/sections/{}".format(section_id),
            headers=self.headers,
            data={"status": 2},
        )

        if r.status_code != 200:
            raise Exception(
                "Failed to connect to meistertask (code: {})".format(r.status_code)
            )
