import argparse

from src.utils import constants
from .projectcli import ProjectCLI
from .taskcli import TaskCLI
from .sectioncli import SectionCLI


class CLI:
    def __init__(self):
        self.parser = argparse.ArgumentParser(
            prog=constants.APP_NAME,
            description=constants.APP_DESCRIPTION,
            epilog="For more info: {}".format(constants.PROJECT_USAGE),
        )
        self.subparsers = self.parser.add_subparsers(
            title="Meistertask core commands",
            dest="command",
            metavar="command",
            help="[project, task]",
        )

        self.project_parser = ProjectCLI(self.subparsers)
        self.project_parser.configure()

        self.task_parser = TaskCLI(self.subparsers)
        self.task_parser.configure()

        self.section_parser = SectionCLI(self.subparsers)
        self.section_parser.configure()

    def parse_args(self):
        args = self.parser.parse_args()
        if not args.command:
            print(constants.ROOT_USAGE)
            exit(1)

        if args.command.startswith("p") and not args.option:
            print(constants.PROJECT_USAGE)
            exit(2)

        if args.command.startswith("t") and not args.option:
            print(constants.TASK_USAGE)
            exit(3)
        return args
