from src.utils import constants


class TaskCLI:
    def __init__(self, subparsers):
        self.subparsers = subparsers
        self.parser = self.subparsers.add_parser(
            "task",
            aliases=["t"],
            description="Manage tasks of a specific project",
        )

    def configure(self):
        task_subparsers = self.parser.add_subparsers(
            title="Task commands",
            dest="option",
            metavar="[create, list, update, delete, move]",
        )
        create_task = task_subparsers.add_parser(
            "create", aliases=["c"], description="Create new task"
        )
        create_task.add_argument("name", help="task name")
        create_task.add_argument("section", help="section name")
        create_task.add_argument("-d", "--description", help="task description")
        create_task.add_argument("project", help="project name")

        list_tasks = task_subparsers.add_parser(
            "list", aliases=["l", "ls"], description="List tasks by section"
        )
        list_tasks.add_argument("project", help="project name")
        list_tasks.add_argument(
            "-s",
            "--section",
            default="all",
            help="List tasks of specific section",
            dest="section",
        )
        list_tasks.add_argument(
            "--short",
            help="List in short format (default: long format)",
            default="long",
            const="short",
            action="store_const",
            dest="format",
        )
        list_tasks.add_argument(
            "--status",
            choices=constants.TASK_STATUS,
            help="List by task status (default: open)",
            dest="status",
            default="open",
        )

        update_task = task_subparsers.add_parser(
            "update", aliases=["u", "e", "edit"], description="Update task details"
        )
        update_task.add_argument("name", help="task name")
        update_task.add_argument("project", help="project name")

        move_task = task_subparsers.add_parser(
            "move", aliases=["m", "mv"], description="Move task to new section"
        )
        move_task.add_argument("name", help="task name")
        move_task.add_argument("section", choices=["open", "inprogress", "done"])
        move_task.add_argument("project", help="project name")
