import requests

from src.core.errors import ProjectError, SectionError, TaskError
from src.utils import Colors


def handle_domain_errors(func):
    def handler(**kwargs):
        try:
            func(kwargs)
        except (ProjectError, SectionError, TaskError) as e:
            print(Colors.wrap(Colors.RED, e))
            exit(1)

    return handler


def handle_http_errors(func):
    def handler(*args):
        try:
            return func(*args)
        except requests.exceptions.ConnectionError:
            print(Colors.wrap(Colors.RED, "No internet connection"))
            exit(2)

    return handler
