from typing import Optional, Set

from src.api import APIProject, APISection
from src.core.models import Project, Section
from src.utils import Colors


class ProjectManager:
    def __init__(self, token: str):
        self.api_section = APISection(token)
        self.api = APIProject(token)

    def create(self, name: str, description=""):
        if len(name) < 3:
            print(
                Colors.wrap(
                    Colors.RED, "Project name must be at least three characters"
                )
            )
            exit(1)

        project = Project(name, description)
        created_project: Project = self.api.create(project)

        print(created_project)
        print(Colors.wrap(Colors.GREEN, "Project create successfully"))

    def update(self, project_name: str):
        """update project name and description"""
        project: Project = self.api.fetch_by_name(project_name)

        if project:
            print(project)

            new_name = str(
                input(Colors.wrap(Colors.YELLOW, "[?] Type name (Enter to skip):"))
            )
            new_description = str(
                input(
                    Colors.wrap(Colors.YELLOW, "[?] Type description (Enter to skip):")
                )
            )

            if new_name and len(new_name):
                project.name = new_name

            if new_description and len(new_description):
                project.description = new_description

            updated_project: Project = self.api.update(project)
            print(updated_project)
            print(Colors.wrap(Colors.GREEN, "Project updated successfully"))
        else:
            print(Colors.wrap(Colors.RED, "No project is found"))

    def remove(self, project_name: str):
        project: Project = self.api.fetch_by_name(project_name)

        if project:
            while True:
                try:
                    choice = str(
                        input(
                            Colors.wrap(
                                Colors.YELLOW,
                                "Do you want to delete this project [y/n]?",
                            )
                        )
                    )
                    if choice.lower() in ["y", "yes", "n", "no"]:
                        break
                    else:
                        raise ValueError("Invalid option")
                except ValueError:
                    print(Colors.wrap(Colors.RED, "Please choose a valid option"))

            if choice.lower() in ["y", "yes"]:
                project: Project = self.api.delete(project.id)
                print(project)
                print(Colors.wrap(Colors.GREEN, "Project is deleted successfully"))
        else:
            print(Colors.wrap(Colors.RED, "Project not found"))

    def archive(self, project_id: int):
        while True:
            try:
                choice = str(
                    input(
                        Colors.wrap(
                            Colors.YELLOW, "Do you want to archive this project [y/n] ?"
                        )
                    )
                )
                if choice.lower() in ["y", "yes", "no", "n"]:
                    break
                else:
                    raise ValueError("Invalid choice")
            except ValueError:
                print(Colors.wrap(Colors.RED, "Please choose a valid option"))

        if choice.lower() in ["y", "yes"]:

            project: Project = self.api.archive(project_id)
            print(project)
            print(Colors.wrap(Colors.GREEN, "Project is archived successfully"))
        else:
            print(Colors.wrap(Colors.RED, "No project is archived"))

    def view(self, name: str):
        projects: Set[Project] = self.api.fetch_all()
        for project in projects:
            if project.name == name:
                print(project)
                break
        else:
            Colors.wrap(Colors.RED, "No project is found")

    def list_all(self, project_type="active", listing_format="short"):
        projects: Set[Project] = self.api.fetch_all(project_type)
        if projects and len(projects):
            for project in projects:
                if listing_format == "short":
                    project.show_summary()
                else:
                    print(project)
            print(
                Colors.wrap(
                    Colors.CYAN, "Total number of projects: {}".format(len(projects))
                )
            )
        else:
            print(Colors.wrap(Colors.RED, "No project is found"))

    def fetch_by_name(self, name: str) -> Optional[Project]:
        project: Project = self.api.fetch_by_name(name)
        return project
