from typing import List, Optional

from src.api import APISection, APIProject
from src.core.models import Section, Project
from src.utils import Colors


class SectionManager:
    def __init__(self, token, project: Project):
        self.api = APISection(token)
        self.project = project

    def list_all(self):
        sections: List[Section] = self.api.fetch_all(self.project.id)

        for section in sections:
            print(section)
        print(
            Colors.wrap(Colors.CYAN, "Total number of sections: ".format(len(sections)))
        )

    def create(self, section_name: str):
        section: Section = Section(section_name, self.project.id)
        created_section: Section = self.api.create(section)
        print(created_section)
        print(Colors.wrap(Colors.GREEN, "Section created successfully"))

    def delete(self, section_name: str):
        section: Section = self.api.fetch_by_name(section_name, self.project.id)
        self.api.delete(section.id)
        print(Colors.wrap(Colors.GREEN, "Section deleted successfully"))

    def fetch_by_name(self, name) -> Optional[Section]:
        return self.api.fetch_by_name(name)
