from typing import Dict, FrozenSet
from datetime import datetime

from .section import Section
from ...utils import Colors


class Project:
    """Project model"""

    project_status = {1: "active", 2: "archived", 3: "all", 4: "deleted", 5: "archived"}

    def __init__(self, name="", description=""):
        self.id = None
        self.name = name
        self.status = self.project_status[1]
        self.description = description
        self.created = None
        self.updated = None

        self.sections: FrozenSet[Section] = frozenset()

    @staticmethod
    def from_json(json: Dict):
        project: Project = Project()
        project.id = json["id"]
        project.name = json["name"]
        project.status = Project.project_status[json["status"]]
        project.description = json["notes"]
        project.created = datetime.fromisoformat(
            json["created_at"].replace("T", " ").replace("Z", "")
        )
        project.updated = datetime.fromisoformat(
            json["updated_at"].replace("T", " ").replace("Z", "")
        )

        return project

    def __repr__(self):
        return "\n".join(
            (
                Colors.wrap(Colors.UNDERLINE, "Name")
                + ": {} / {}".format(self.name, self.id),
                Colors.wrap(Colors.UNDERLINE, "Status") + ": {}".format(self.status),
                Colors.wrap(Colors.UNDERLINE, "Description")
                + ": {}".format(self.description),
                Colors.wrap(Colors.UNDERLINE, "Created")
                + ": {} / ".format(self.created)
                + Colors.wrap(Colors.UNDERLINE, "Updated")
                + ": {}".format(self.updated),
                "\n",
            )
        )

    def show_summary(self):
        short_description = (
            self.description[0:10] + " ..."
            if self.description and len(self.description)
            else "No Description"
        )
        print(
            Colors.wrap(Colors.UNDERLINE, "Project")
            + ": {} / {}".format(self.name, short_description)
        )

    def show_details(self):
        print(self)
        if len(self.sections):
            for section in self.sections:
                section.show_details()
        else:
            print("No section / task is available on this project")
