#!/usr/bin/python3

from typing import List
import os

from src.core.models import Section
from .colors import Colors
from . import constants


def get_auth_key() -> str:
    """Read auth key from environment variable.
    Variable name: MEISTERTASK
    """
    try:
        return str(os.environ["MEISTERTASK"])
    except KeyError:
        print(Colors.wrap(Colors.RED, "Authentication key is required"))
        print(Colors.wrap(Colors.RED, "Hint: export MEISTERTASK='auth-key-here'"))
        print(
            Colors.wrap(
                Colors.CYAN, "For more info: {}".format(constants.GITHUB_REPOSITORY)
            )
        )
        exit(1)


def prompt_for_one_section(sections: List[Section]) -> Section:
    """Prompt the user to choose only one section"""
    for index, section in enumerate(sections):
        print("\t[{}] {}".format(index, section.name))
    print(Colors.wrap(Colors.YELLOW, "Multiple sections are found, select one"))

    while True:
        try:
            choice = int(input(Colors.wrap(Colors.YELLOW, "[?] Section id: ")))
            if 0 <= choice < len(sections):
                return sections[choice]
            else:
                raise ValueError("Invalid option")
        except ValueError:
            print(Colors.wrap(Colors.RED, "Please select valid id."))


if __name__ == "__main__":
    print("This module is indented to be included only")
