import unittest
import unittest.mock

from src.core.models import Project


class TestProjectFromJson(unittest.TestCase):
    def test_from_valid_json(self):
        project_json = {
            "id": 123,
            "token": "s3i5reaF",
            "name": "Getting Started with MeisterTask",
            "notes": "This is just a demo project",
            "status": 1,
            "created_at": "2017-01-13T09:29:36.360375Z",
            "updated_at": "2017-01-16T10:10:21.460697Z"
        }

        project: Project = Project.from_json(project_json)
        self.assertEqual(project.id, 123)
        self.assertEqual(project.name, "Getting Started with MeisterTask")
        self.assertEqual(project.description, "This is just a demo project")
        self.assertEqual(project.status, "active")

    def test_with_null_description(self):
        project_json = {
            "id": 124,
            "token": "ly1P1nbX",
            "name": "Project X",
            "notes": None,
            "status": 2,
            "created_at": "2017-01-16T13:22:04.114709Z",
            "updated_at": "2017-01-16T15:40:16.676466Z"
        }

        project: Project = Project.from_json(project_json)
        self.assertEqual(project.id, 124)
        self.assertEqual(project.name, "Project X")
        self.assertEqual(project.description, None)
        self.assertEqual(project.status, "archived")


if __name__ == '__main__':
    unittest.main()
