import unittest

from src.cli import CLI


class TestTaskCommand(unittest.TestCase):
    def test_listing(self):
        parser = CLI().parser

        list_all_args = parser.parse_args(["task", "list", "projectname"])
        self.assertEqual(list_all_args.command, "task")
        self.assertEqual(list_all_args.option, "list")
        self.assertEqual(list_all_args.project, "projectname")

    def test_listing_with_short_format(self):
        parser = CLI().parser

        args = parser.parse_args(["task", "ls", "--short", "projectname"])

        self.assertEqual(args.command, "task")
        self.assertEqual(args.option, "ls")
        self.assertEqual(args.format, "short")
        self.assertEqual(args.project, "projectname")

    def test_listing_with_section(self):
        parser = CLI().parser

        args = parser.parse_args(["task", "ls", "-s", "sectionname", "projectname"])
        self.assertEqual(args.command, "task")
        self.assertEqual(args.option, "ls")
        self.assertEqual(args.section, "sectionname")
        self.assertEqual(args.project, "projectname")

        args = parser.parse_args(["task", "ls", "projectname"])
        self.assertEqual(args.command, "task")
        self.assertEqual(args.option, "ls")
        self.assertEqual(args.section, "all")
        self.assertEqual(args.project, "projectname")

    def test_listing_with_task_status(self):
        parser = CLI().parser

        args = parser.parse_args(['task', 'ls', 'projectname'])
        self.assertEqual(args.status, 'open')

        args = parser.parse_args(['task', 'ls', '--status', 'completed', 'projectname'])
        self.assertEqual(args.status, 'completed')

    def test_create(self):
        parser = CLI().parser

        args = parser.parse_args(
            ["task", "create", "-d", "description", "taskname", 'sectionname', "projectname"]
        )
        self.assertEqual(args.command, "task")
        self.assertEqual(args.option, "create")
        self.assertEqual(args.name, "taskname")
        self.assertEqual(args.section, "sectionname")
        self.assertEqual(args.project, "projectname")
        self.assertEqual(args.description, "description")

    def test_update(self):
        parser = CLI().parser

        args = parser.parse_args(["task", "update", "taskname", "projectname"])
        self.assertEqual(args.command, "task")
        self.assertEqual(args.option, "update")
        self.assertEqual(args.name, "taskname")
        self.assertEqual(args.project, "projectname")

    def test_moving(self):
        parser = CLI().parser

        args = parser.parse_args(["task", "move", "taskname", "open", "projectname"])
        self.assertEqual(args.option, "move")
        self.assertEqual(args.section, "open")
        self.assertEqual(args.name, "taskname")
        self.assertEqual(args.project, "projectname")


if __name__ == "__main__":
    unittest.main()
